@@ -13,8 +13,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see http://www.gnu.org/licenses/
 
-import locale
+import codecs, locale
 ENCODING    = locale.getdefaultlocale()[1]
+try:
+    codecs.lookup(ENCODING)
+except:
+    ENCODING    = locale.getpreferredencoding()
+    try:
+        codecs.lookup(ENCODING)
+    except:
+        ENCODING= 'utf-8'
 
 def ensure_unicode(x,encoding=ENCODING,errors='replace'):
     if type(x) is unicode: return x
