@@ -253,6 +253,8 @@ class FilesDialog(dialogs.FilesDialog,_IconDialog):
 class ProgressDialog(wx.ProgressDialog,ProgressReceiver):
     """+1 is added because eg opening a file is also an action"""
     def __init__(self,parent,title,parent_max=1,child_max=1,message=''):
+        if message == '':
+            message = '.'*80
         ProgressReceiver.__init__(self,parent_max,child_max)
         wx.ProgressDialog.__init__(self,
                 title   = title,
