@@ -81,9 +81,13 @@ class NotImplementedError(Exception):
             %(self.instance.__class__.__name__,self.method)
     
 #---base controls
+def untranslated(self,x):
+    return x
+
 class _Ctrl(object):
-    _to_local       = str
-    _to_english     = str
+    _to_local       = untranslated
+    _to_english     = untranslated
+    _busy_cursor    = False
     
     def Set(self,value):
         self.SetValue(self._to_local(value))
@@ -414,6 +418,7 @@ class AutoCompleteDictionaryFileCtrl(DictionaryFileCtrl):
         
 class FontFileCtrl(AutoCompleteDictionaryFileCtrl):
     _label      = _t('Fonts')
+    _busy_cursor    = True
     
     def GetDefaultPath(self):
         value           = self.path.GetValue()
@@ -576,12 +581,17 @@ class EditPanel(wx.Panel):
         if issubclass(Ctrl,TextCtrl):
             border = max(border,TEXTCTRL_BORDER)
         #create ctrl instance
+        if Ctrl._busy_cursor:
+            wx.BeginBusyCursor()
         self.edit       = Ctrl(self,value=value_as_string,
                             size=(height,height-2*border),**extra)
         #check min size
         if self.edit.GetSize()[1] > height:
             self.edit.SetMinSize((self.edit.GetMinSize()[0],height))
         self.edit.SetFocus()
+        if Ctrl._busy_cursor:
+            wx.EndBusyCursor()
+            print 'busy'
         return border
         
     def _Layout(self,offset,height,border,label):
