@@ -161,7 +161,6 @@ class Frame(wx.Frame):
 
     def __set_properties(self):
         # begin wxGlade: Frame.__set_properties
-        self.SetSize((400, 600))
         self.frame_statusbar.SetStatusWidths([-1])
         # statusbar fields
         frame_statusbar_fields = [""]
@@ -179,8 +178,8 @@ class Frame(wx.Frame):
         sizer_1.Add(self.tree, 1, wx.EXPAND, 0)
         sizer_1.Add(self.empty, 1, wx.EXPAND|wx.ALIGN_CENTER_HORIZONTAL|wx.ALIGN_CENTER_VERTICAL, 0)
         self.SetSizer(sizer_1)
+        sizer_1.Fit(self)
         self.Layout()
-        self.SetSize((400, 600))
         # end wxGlade
 
     def on_menu_file_new(self, event): # wxGlade: Frame.<event_handler>
